@@ -2,13 +2,15 @@ from .gql_handler import *
 from datetime import datetime
 
 class PyXploraApi:
-    def __init__(self, countryPhoneNumber: str, phoneNumber: str, password: str, userLang: str, timeZone: str):
+    def __init__(self, countryPhoneNumber: str, phoneNumber: str, password: str, userLang: str, timeZone: str, watchNo: int=0):
         self.handler = GQLHandler(countryPhoneNumber, phoneNumber, password, userLang, timeZone)
         self.handler.login()
 
+        self.watch_no = watchNo
+
         self.myInfo = self.handler.getMyInfo()['readMyInfo']
-        self.watch_user_id = self.myInfo['children'][0]['ward']['id']
-        self.watch_user_name = self.myInfo['children'][0]['ward']['name']
+        self.watch_user_id = self.myInfo['children'][self.watch_no]['ward']['id']
+        self.watch_user_name = self.myInfo['children'][self.watch_no]['ward']['name']
 
         self.watch_last_location = self.handler.getWatchLastLocation(self.watch_user_id)['watchLastLocate']
 
@@ -25,7 +27,7 @@ class PyXploraApi:
                 xcoin = contact['contactUser']['xcoin']
                 id = contact['contactUser']['id']
             except KeyError and TypeError:
-                xcoin = -1
+                xcoin = -1 # None - XCoins
                 id = None
             self.contacts.append({
                 'id': id,
@@ -39,6 +41,8 @@ class PyXploraApi:
         return self.contacts
 
 ##### User Info #####
+    def getUserID(self):
+        return self.myInfo['id']
     def getUserName(self):
         return self.myInfo['name']
     def getUserIcon(self):
@@ -56,11 +60,9 @@ class PyXploraApi:
 
 ##### Watch Info #####
     def getWatchCurrentStep(self):
-        return self.myInfo['children'][0]['ward']['currentStep']
-
+        return self.myInfo['children'][self.watch_no]['ward']['currentStep']
     def getWatchTotalStep(self):
-        return self.myInfo['children'][0]['ward']['totalStep']
-
+        return self.myInfo['children'][self.watch_no]['ward']['totalStep']
     def getWatchAlarm(self):
         for alarm in self.handler.getAlarms(self.watch_user_id)['alarms']:
             self.alarms.append({
@@ -70,25 +72,20 @@ class PyXploraApi:
                 'status': alarm['status'],
             })
         return self.alarms
-
     def getWatchUserID(self):
         return self.watch_user_id
-
     def getWatchUserName(self):
         return self.watch_user_name
-
     def getWatchXcoin(self):
         return self.myInfo[0]['ward']['xcoin']
-
     def getWatchBattery(self):
         return self.watch_last_location['battery']
-
     def getWatchIsCharging(self):
         return self.watch_last_location['isCharging']
-
+    def getWatchOnlineStatus(self):
+        return self.handler.getWatches(self.watch_user_id)['watches'][self.watch_no]['onlineStatus']
     def getWatchUnReadChatMsgCount(self): # bug?
         return self.handler.unReadChatMsgCount(self.watch_user_id)['unReadChatMsgCount']
-
     def getWatchChats(self): # bug?
         for chat in self.handler.chats(self.watch_user_id)['chats']['list']:
             self.chats.append({
@@ -109,10 +106,8 @@ class PyXploraApi:
 ##### Watch Location Info #####
     def getWatchLastLocation(self):
         return self.watch_last_location
-
     def getWatchLocateType(self):
         return self.watch_last_location['locateType']
-
     def getWatchLocate(self):
         return {
             'tm': datetime.fromtimestamp(self.watch_last_location['tm']).strftime('%Y-%m-%d %H:%M:%S'),
@@ -124,13 +119,10 @@ class PyXploraApi:
             'province': self.watch_last_location['province'],
             'country': self.watch_last_location['country'],
         }
-
     def getWatchIsInSafeZone(self):
         return self.watch_last_location['isInSafeZone']
-
     def getWatchSafeZoneLabel(self):
         return self.watch_last_location['safeZoneLabel']
-
     def getSafeZones(self):
         for safeZone in self.handler.safeZones(self.watch_user_id)['safeZones']:
             self.safe_zones.append({
@@ -143,13 +135,12 @@ class PyXploraApi:
                 'address': safeZone['address'],
             })
         return self.safe_zones
-
     def trackWatchInterval(self):
         return self.handler.trackWatch(self.watch_user_id)['trackWatch']
-
     def askWatchLocate(self):
         return self.handler.askWatchLocate(self.watch_user_id)['askWatchLocate']
 
+##### Feature #####
     def schoolSilentMode(self):
         for sientTime in self.handler.silentTimes(self.watch_user_id)['silentTimes']:
             self.school_silent_mode.append({
@@ -160,31 +151,28 @@ class PyXploraApi:
                 'status': sientTime['status'],
             })
         return self.school_silent_mode
-
     def setEnableSilentTime(self, silentId):
         return self.handler.setEnableSlientTime(silentId)['setEnableSilentTime']
-
     def setDisableSilentTime(self, silentId):
         return self.handler.setEnableSlientTime(silentId, NormalStatus.DISABLE)['setEnableSilentTime']
-
     def setAllEnableSilentTime(self):
         res = []
-        for time in self.schoolSilentMode():
-            res.append(self.setEnableSilentTime(time['id']))
+        for silentTime in self.schoolSilentMode():
+            res.append(self.setEnableSilentTime(silentTime['id']))
         return res
-
     def setAllDisableSilentTime(self):
         res = []
-        for time in self.schoolSilentMode():
-            res.append(self.setDisableSilentTime(time['id']))
+        for silentTime in self.schoolSilentMode():
+            res.append(self.setDisableSilentTime(silentTime['id']))
         return res
-
+    def sendText(self, text): # sender is login User
+        return self.handler.sendText(self.watch_user_id, text)
     def shutdown(self):
         return self.handler.shutdown(self.watch_user_id)
-
     def reboot(self):
         return self.handler.reboot(self.watch_user_id)
 
+##### - #####
     def helperTime(self, time):
         h = str(int(time) /60).split('.')
         h2 = str(int(h[1]) *60).zfill(2)[:2]
